import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { OAuthApp, UpdateOAuthApp, OAuthAppsQueryBuilder, OAuthAppCreatedEnvelope, OAuthAppDeletedEnvelope, OAuthAppUpdatedEnvelope } from './index.typings.js';
export { ActionEvent, Asset, BaseEventMetadata, CreateOAuthAppRequest, CreateOAuthAppResponse, CursorPaging, Cursors, DeleteContext, DeleteOAuthAppRequest, DeleteOAuthAppResponse, DeleteStatus, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, GenerateOAuthAppSecretRequest, GenerateOAuthAppSecretResponse, GetOAuthAppRequest, GetOAuthAppResponse, IdentificationData, IdentificationDataIdOneOf, MessageEnvelope, MetaSiteSpecialEvent, MetaSiteSpecialEventPayloadOneOf, Namespace, NamespaceChanged, OAuthAppType, OAuthAppsQueryResult, OAuthTechnologies, OdeditorAssigned, OdeditorUnassigned, Paging, PagingMetadataV2, PicassoAssigned, PicassoUnassigned, PlatformQuery, PlatformQueryPagingMethodOneOf, QueryOAuthAppsRequest, QueryOAuthAppsResponse, RestoreInfo, ServiceProvisioned, ServiceRemoved, SiteCreated, SiteCreatedContext, SiteDeleted, SiteHardDeleted, SiteMarkedAsTemplate, SiteMarkedAsWixSite, SitePublished, SitePurgedExternally, SiteRenamed, SiteTransferred, SiteUndeleted, SiteUnpublished, SiteUrlChanged, SortOrder, Sorting, State, StudioAssigned, StudioUnassigned, UpdateOAuthAppRequest, UpdateOAuthAppResponse, WebhookIdentityType, WixPagesDomainMapping } from './index.typings.js';

type OAuthAppNonNullablePaths = `allowedRedirectUris` | `allowedRedirectDomains` | `applicationType` | `technology` | `wixPagesDomainsMappings` | `wixPagesDomainsMappings.${number}.origin` | `wixPagesDomainsMappings.${number}.destination`;
declare function createOAuthApp$1(httpClient: HttpClient): CreateOAuthAppSignature;
interface CreateOAuthAppSignature {
    /**
     * Creates a new OAuth app for a Wix Headless client.
     *
     * Use this API to enable headless functionality for a Wix site. An OAuth app allows external sites or apps to securely access your site's data and services using Wix APIs.
     * @param - OAuth app to create.
     * @returns Created OAuth app info.
     */
    (oAuthApp: NonNullablePaths<OAuthApp, `name`>): Promise<NonNullablePaths<OAuthApp, OAuthAppNonNullablePaths>>;
}
declare function getOAuthApp$1(httpClient: HttpClient): GetOAuthAppSignature;
interface GetOAuthAppSignature {
    /**
     * Retrieves an OAuth app by ID.
     * @param - ID of the OAuth app to retrieve.
     * @returns Retrieved OAuth app info.
     */
    (oAuthAppId: string): Promise<NonNullablePaths<OAuthApp, OAuthAppNonNullablePaths>>;
}
declare function updateOAuthApp$1(httpClient: HttpClient): UpdateOAuthAppSignature;
interface UpdateOAuthAppSignature {
    /**
     * Updates an OAuth app.
     *
     *
     * Only fields provided in `mask.paths` are updated.
     *
     * You can update the following fields:
     * + `name`
     * + `description`
     * + `allowedDomain`
     * + `loginUrl`
     * + `logoutUrl`
     * + `technology`
     * @param - ID of the OAuth app.
     * @param - Explicit list of fields to update. Only fields listed are updated.
     * @returns Updated OAuth app info.
     */
    (_id: string, oAuthApp: UpdateOAuthApp, mask: string[]): Promise<NonNullablePaths<OAuthApp, OAuthAppNonNullablePaths>>;
}
declare function queryOAuthApps$1(httpClient: HttpClient): QueryOAuthAppsSignature;
interface QueryOAuthAppsSignature {
    /**
     * Retrieves a list of OAuth apps, given the provided paging, filtering, and sorting.
     *
     *
     * Query OAuth Apps runs with these defaults, which you can override:
     * + Results are sorted by `id` in descending order.
     * + `paging.offset` is `0`.
     */
    (): OAuthAppsQueryBuilder;
}
declare const onOAuthAppCreated$1: EventDefinition<OAuthAppCreatedEnvelope, "wix.headless.v1.o_auth_app_created">;
declare const onOAuthAppDeleted$1: EventDefinition<OAuthAppDeletedEnvelope, "wix.headless.v1.o_auth_app_deleted">;
declare const onOAuthAppUpdated$1: EventDefinition<OAuthAppUpdatedEnvelope, "wix.headless.v1.o_auth_app_updated">;

declare const createOAuthApp: MaybeContext<BuildRESTFunction<typeof createOAuthApp$1> & typeof createOAuthApp$1>;
declare const getOAuthApp: MaybeContext<BuildRESTFunction<typeof getOAuthApp$1> & typeof getOAuthApp$1>;
declare const updateOAuthApp: MaybeContext<BuildRESTFunction<typeof updateOAuthApp$1> & typeof updateOAuthApp$1>;
declare const queryOAuthApps: MaybeContext<BuildRESTFunction<typeof queryOAuthApps$1> & typeof queryOAuthApps$1>;
/**
 * Triggered when an OAuth app is created.
 */
declare const onOAuthAppCreated: BuildEventDefinition<typeof onOAuthAppCreated$1>;
/**
 * Triggered when an OAuth app is deleted.
 */
declare const onOAuthAppDeleted: BuildEventDefinition<typeof onOAuthAppDeleted$1>;
/**
 * Triggered when an OAuth app is updated.
 */
declare const onOAuthAppUpdated: BuildEventDefinition<typeof onOAuthAppUpdated$1>;

export { OAuthApp, OAuthAppCreatedEnvelope, OAuthAppDeletedEnvelope, OAuthAppUpdatedEnvelope, OAuthAppsQueryBuilder, UpdateOAuthApp, createOAuthApp, getOAuthApp, onOAuthAppCreated, onOAuthAppDeleted, onOAuthAppUpdated, queryOAuthApps, updateOAuthApp };
